% CALIB_NCC4 - 
% calibration of growth model w/ endogenous growth and cash and credit
% discrete time model

eps		= 0.99;
bet	    = 0.6;

betay	= 0.947;
beta	= betay^0.25;	% discount factor
gamma   = 0.13;  
deltaK	= 0.012;		% quarterly discountfactor
deltaH	= 0.012;		% quarterly discountfactor
% 
theta	= 2;
alpha   = 3.2;
a       = 0.224; %M1/C=.224 over 1972-2004,

% specification of shocks
eta		= 0.86;   %money persistence
rho		= 0.93; %goods productivity persistence
nu		= 0.93;  %credit persistence

gy      = 0.02;
g       = (1+gy)^0.25-1;
piy	  	= 0.05;			            % Chari, Jones, Manuelli (1996)
pi		= (1+piy)^(1/4)-1;	        % quarterly inflation rate
sigmay	= (1+gy)*(1+piy)-1;			% money growth rate
sigma   = (1+sigmay)^0.25-1;
r		= (1+g)^theta/beta-1;        % gross real interest rate 
rgr     = r+deltaK;                 % net return to capital
R       = (1+r)*(1+pi)-1;
x  		= 0.7;					    %0.7 leisure time (Jones93)

rhod    = 1/beta-1;                  % discount rate
% 
omeg    = (1-eps)/(1-eps+bet);
Omega   = ((1-bet)^(1-bet)*bet^bet)^omeg*((1-eps)^(1-eps)*eps^eps)^(1-omeg);
omega0  = eps^(1+bet)/((1-bet))^(1-bet)/((1-eps)*bet)^bet;
omega1  = omega0^(1/(1-eps+bet));
omega3  = bet*(1-eps)/(1-bet)/eps;
omega4  = bet*(1-gamma)/(1-bet)/gamma;
A1      = (1-bet)*omega3^bet*omega0;

AG      = 1;
AH      = ((r+deltaK)/Omega)^(1/(1-omeg))/(1-x)/AG^(omeg/(1-omeg));
lHsHc   = omega1*(AH/AG*(1-x))^(1/(1-eps+bet));
lGsGc   = bet/(1-bet)*(1-eps)/eps*lHsHc;
w       = bet*AG/lGsGc^(1-bet);
AF      = 1.6;
AF      = (1-a)^(1-gamma)/(gamma*R/w)^gamma;

x       = fzero('XXKHB',x);

lHsHc   = omega1*(AH/AG*(1-x))^(1/(1-eps+bet));
lGsGc   = bet/(1-bet)*(1-eps)/eps*lHsHc;
rhat    = Omega*AG^omeg*AH^(1-omeg)*(1-x)^(1-omeg);
r       = rhat-deltaK;
g       = ((1+rhat-deltaK)/(1+rhod))^(1/theta)-1;
w       = bet*AG/lGsGc^(1-bet);
pi      = (1+sigma)/(1+g)-1;
R       = (1+r)*(1+pi)-1;
lH      = (g+deltaH)/AH*lHsHc^(1-eps);
a       = 1-(gamma*R/w*AF^(1/gamma))^(gamma/(1-gamma));
F       = ((1-a)/AF)^(1/gamma);
c_h     = w/(1+w*F+R*a)*x/alpha;
apG     = AG*lGsGc^bet;
h_k     = (apG-g-deltaK)/(c_h+apG/lHsHc*lH);
c_k     = c_h*h_k;
sG      = (g+deltaK+c_k)/apG;
lF      = F*c_h;
lG      = 1-x-lF-lH;

s       = sG;
L       = lG;
f       = lF;
k_h     = 1/h_k;
y_h     = AG*(s*k_h)^(1-bet)*L^bet;             % y/h 
i_h     = y_h-c_h;                        % i/h
H2      = eps*AH*((1-s)*k_h/(1-x-L-f))^(1-eps);
H_h     = AH*((1-s)*k_h)^(1-eps)*(1-x-L-f)^eps;
gh      = AH*((1-s)*k_h)^(1-eps)*(1-x-L-f)^eps+1-deltaH;

s1      = s/(1-s);
x1		= x/(1-x-L-f);
f1		= f/(1-x-L-f);
L1		= L/(1-x-L-f);

r1		= r/(1+r);
pi1	    = pi/(1+pi);
R1		= R/(1+R);
a1      = a/(1-a);
gamma1  = gamma/(1-gamma);
Ra1     = 1+R*a+w*F;
H21     = H2*(1-x)/(1+H2*(1-x)-deltaH);

